==> box64_0.3.2+dfsg.orig.tar.xz: box64-0.3.2/src/wrapped32/wrappedlibxrender_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh...
#endif

GO(XRenderAddGlyphs, vFXLppipi)
GO(XRenderAddTraps, vFXLiipi)
GO(XRenderChangePicture, vFXLLp)
GO(XRenderComposite, vFXiLLLiiiiiiuu)
GO(XRenderCompositeDoublePoly, vFXiLLpiiiipii)
GO(XRenderCompositeString16, vFXiLLrLiiuL_Liiiipi)
GO(XRenderCompositeString32, vFXiLLrLiiuL_Liiiipi)
GO(XRenderCompositeString8, vFXiLLrLiiuL_Liiiipi)
GO(XRenderCompositeText16, vFXiLLrLiiuL_iiiipi)
GO(XRenderCompositeText32, vFXiLLrLiiuL_iiiipi)
GO(XRenderCompositeText8, vFXiLLrLiiuL_iiiipi)
GO(XRenderCompositeTrapezoids, vFXiLLrLiiuL_iipi)
GO(XRenderCompositeTriangles, vFXiLLpiipi)
GO(XRenderCompositeTriFan, vFXiLLpiipi)
GO(XRenderCompositeTriStrip, vFXiLLpiipi)
GO(XRenderCreateAnimCursor, LFXip)
GO(XRenderCreateConicalGradient, LFXpppi)
GO(XRenderCreateCursor, LFXLuu)
GO(XRenderCreateGlyphSet, LFXrLiiuL_)
GO(XRenderCreateLinearGradient, LFXpppi)
GO(XRenderCreatePicture, LFXLrLiiuL_Lp)
GO(XRenderCreateRadialGradient, LFXpppi)
GO(XRenderCreateSolidFill, LFXp)
//DATAB(XRenderExtensionInfo, sizeof(ptr_t))
//DATA(XRenderExtensionName, sizeof(ptr_t))   //D
GO(XRenderFillRectangle, vFXiLpiiuu)
GO(XRenderFillRectangles, vFXiLppi)
//GO(XRenderFindDisplay, pFp)
GOM(XRenderFindFormat, pFEXLrLiiuL_i)
GOM(XRenderFindStandardFormat, pFEXi)
GOM(XRenderFindVisualFormat, pFEXp)
GO(XRenderFreeGlyphs, vFXLpi)
GO(XRenderFreeGlyphSet, vFXL)
GO(XRenderFreePicture, vFXL)
GO(XRenderParseColor, iFXpp)
GO(XRenderQueryExtension, iFXpp)
GO(XRenderQueryFilters, pFXL)
GO(XRenderQueryFormats, iFX)
GO(XRenderQueryPictIndexValues, pFXrLiiuL_p)
GO(XRenderQuerySubpixelOrder, iFXi)
GO(XRenderQueryVersion, iFXpp)
GO(XRenderReferenceGlyphSet, LFXL)
GO(XRenderSetPictureClipRectangles, vFXLiipi)
GO(XRenderSetPictureClipRegion, vFXLp)
GO(XRenderSetPictureFilter, vFXLppi)
GO(XRenderSetPictureTransform, vFXLp)
GO(XRenderSetSubpixelOrder, iFXii)

==> box64_0.3.4+dfsg.orig.tar.xz: box64-0.3.4/src/wrapped32/wrappedlibxrender_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh...
#endif

// XRenderPictureAttributes = iLiiiiLiiiiLi
// XRenderDirectFormat = wwwwwwww
// XRenderPictFormat = LiiwwwwwwwwL

GO(XRenderAddGlyphs, vFXLppipi)
GO(XRenderAddTraps, vFXLiipi)
GO(XRenderChangePicture, vFXLLp)
GO(XRenderComposite, vFXiLLLiiiiiiuu)
GO(XRenderCompositeDoublePoly, vFXiLLpiiiipii)
GO(XRenderCompositeString16, vFXiLLrLiiwwwwwwwwL_Liiiipi)
GO(XRenderCompositeString32, vFXiLLrLiiwwwwwwwwL_Liiiipi)
GO(XRenderCompositeString8, vFXiLLrLiiwwwwwwwwL_Liiiipi)
GO(XRenderCompositeText16, vFXiLLrLiiwwwwwwwwL_iiiipi)
GO(XRenderCompositeText32, vFXiLLrLiiwwwwwwwwL_iiiipi)
GO(XRenderCompositeText8, vFXiLLrLiiwwwwwwwwL_iiiipi)
GO(XRenderCompositeTrapezoids, vFXiLLrLiiwwwwwwwwL_iipi)
GO(XRenderCompositeTriangles, vFXiLLpiipi)
GO(XRenderCompositeTriFan, vFXiLLpiipi)
GO(XRenderCompositeTriStrip, vFXiLLpiipi)
GO(XRenderCreateAnimCursor, LFXip)
GO(XRenderCreateConicalGradient, LFXpppi)
GO(XRenderCreateCursor, LFXLuu)
GO(XRenderCreateGlyphSet, LFXrLiiwwwwwwwwL_)
GO(XRenderCreateLinearGradient, LFXpppi)
GO(XRenderCreatePicture, LFXLrLiiwwwwwwwwL_LriLiiiiLiiiiLi_)
GO(XRenderCreateRadialGradient, LFXpppi)
GO(XRenderCreateSolidFill, LFXp)
//DATAB(XRenderExtensionInfo, sizeof(ptr_t))
//DATA(XRenderExtensionName, sizeof(ptr_t))   //D
GO(XRenderFillRectangle, vFXiLpiiuu)
GO(XRenderFillRectangles, vFXiLppi)
//GO(XRenderFindDisplay, pFp)
GOM(XRenderFindFormat, pFEXLrLiiwwwwwwwwL_i)
GOM(XRenderFindStandardFormat, pFEXi)
GOM(XRenderFindVisualFormat, pFEXp)
GO(XRenderFreeGlyphs, vFXLpi)
GO(XRenderFreeGlyphSet, vFXL)
GO(XRenderFreePicture, vFXL)
GO(XRenderParseColor, iFXpp)
GO(XRenderQueryExtension, iFXpp)
GO(XRenderQueryFilters, pFXL)
GO(XRenderQueryFormats, iFX)
GO(XRenderQueryPictIndexValues, pFXrLiiwwwwwwwwL_p)
GO(XRenderQuerySubpixelOrder, iFXi)
GO(XRenderQueryVersion, iFXpp)
GO(XRenderReferenceGlyphSet, LFXL)
GO(XRenderSetPictureClipRectangles, vFXLiipi)
GO(XRenderSetPictureClipRegion, vFXLp)
GO(XRenderSetPictureFilter, vFXLppi)
GO(XRenderSetPictureTransform, vFXLp)
GO(XRenderSetSubpixelOrder, iFXii)
